#!/system/bin/sh
# The Mx Project
# Copyright (C) 2018 Hybrid Development Team and Jovic77@XDA
#=======================================================================#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of The Linux Foundation nor
#       the names of its contributors may be used to endorse or promote
#       products derived from this software without specific prior written
#       permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#=======================================================================#
# Performance optimizations for Mx5
# Revision 20180604

# Global variables for performance optimizations
swap_file_size_mb=480;
min_swap_size_mb=20;
min_free_space_mb=50;

version_swap_cache="V3.00"
partition="/data";
sub_dir="swap";
swap_file_name="swap.img";
swappiness=80;

log_file_name="MX5OPT_log.log";
log_file_path="/data/mx_five";

delete_flag=0;
exit_flag=0;
available_blocks=0;
block_size=0;
available_size_mb=0;
current_size_mb=0;
swap_file="";

# Script starts here
log_file=$log_file_path/$log_file_name;
mkdir -p $log_file_path;
if [ -e $log_file ] ; then rm $log_file; fi;


echo "[MX5OPT] The Mx5 Project - Performance optimizations are running" >> $log_file;
echo "[MX5OPT] Hybrid Development Team" >> $log_file;
mount -o remount,rw /
mount -o remount,rw rootfs
mount -o remount,rw /system

# kill audit process first
killall -9 audit;

# clean caches and unnecessary log files
echo "[MX5OPT] Cleaning unnecessary log and cache" >> $log_file;
rm -f /cache/*.apk 2 > /dev/null;
rm -f /cache/*.tmp 2 > /dev/null;
rm -f /cache/*.log 2 > /dev/null;
rm -f /cache/*.txt 2 > /dev/null;
rm -f /cache/recovery/* 2 > /dev/null;
rm -f /data/*.log 2 > /dev/null;
rm -f /data/*.txt 2 > /dev/null;
rm -f /data/anr/*.log 2 > /dev/null;
rm -f /data/anr/*.txt 2 > /dev/null;
rm -f /data/backup/pending/*.tmp 2 > /dev/null;
rm -f /data/cache/*.* 2 > /dev/null;
rm -f /data/dalvik-cache/*.apk 2 > /dev/null;
rm -f /data/dalvik-cache/*.tmp 2 > /dev/null;
rm -f /data/dalvik-cache/*.log 2 > /dev/null;
rm -f /data/dalvik-cache/*.txt 2 > /dev/null;
rm -f /data/data/*.log 2 > /dev/null;
rm -f /data/data/*.txt 2 > /dev/null;
rm -f /data/log/*.log 2 > /dev/null;
rm -f /data/log/*.txt 2 > /dev/null;
rm -f /data/local/*.apk 2 > /dev/null;
rm -f /data/local/*.log 2 > /dev/null;
rm -f /data/local/*.txt 2 > /dev/null;
rm -f /data/local/tmp/*.log 2 > /dev/null;
rm -f /data/local/tmp/*.txt 2 > /dev/null;
rm -f /data/last_alog/*.log 2 > /dev/null;
rm -f /data/last_alog/*.txt 2 > /dev/null;
rm -f /data/last_kmsg/*.log 2 > /dev/null;
rm -f /data/last_kmsg/*.txt 2 > /dev/null;
rm -f /data/mlog/* 2 > /dev/null;
rm -f /data/tombstones/*.log 2 > /dev/null;
rm -f /data/tombstones/*.txt 2 > /dev/null;
rm -f /data/system/*.log 2 > /dev/null;
rm -f /data/system/*.txt 2 > /dev/null;
rm -f /data/system/dropbox/*.log 2 > /dev/null;
rm -f /data/system/dropbox/*.txt 2 > /dev/null;
rm -f /data/system/usagestats/*.log 2 > /dev/null;
rm -f /data/system/usagestats/*.txt 2 > /dev/null;
rm -rf /sd*/LOST.DIR 2 > /dev/null;
export sampling_rate=10000;
export up_threshold=80;
sync;
sysctl -w vm.drop_caches=3;
sleep 1;
sysctl -w vm.drop_caches=0;
echo "[MX5OPT] Caches are dropped!" >> $log_file;

# enable SWAP support
echo "[MX5OPT] Enabling SWAP support" >> $log_file;
echo "[MX5OPT] Partition info:" >> $log_file;
echo "[MX5OPT] partition:\t"$partition >> $log_file;
available_blocks=`stat -t -f $partition | awk '{ print $7 }'`;
block_size=`stat -t -f $partition | awk '{ print $5 }'`;
available_size_mb=$((($available_blocks*($block_size/1024))/1024));
echo "[MX5OPT] free blocks:\t"$available_blocks" blocks" >> $log_file;
echo "[MX5OPT] block size:\t"$block_size" Byte" >> $log_file;
echo "[MX5OPT] free space:\t"$available_size_mb" MB" >> $log_file;
if [ $partition = "/cache" -o $partition = "/data" -o $partition = "/system" ] ;
then
    echo "[MX5OPT] >partition $partition is allowed" >> $log_file;
    echo "[MX5OPT] >check mount state (rw or ro)"  >> $log_file;
    mount_state=`mount | grep -e " $partition " | grep -o -e "rw," -e "ro,"`;
    if [ $mount_state = "ro," -o $mount_state = "rw," ] ;
    then
        if [ $mount_state = "ro," ] ;
        then
            echo "[MX5OPT]  partition is read-only" >> $log_file;
            echo "[MX5OPT]  remount necessary - try ..." >> $log_file;
            mount -o remount,rw $partition;
            echo "[MX5OPT]  checking remount ..." >> $log_file;
            mount_state=`mount | grep -e " $partition " | grep -o -e "rw," -e "ro,"`;
            if [ $mount_state = "rw," ] ;
            then
                echo "[MX5OPT]  remount was successful!" >> $log_file;
                echo "[MX5OPT]  partition is read-write" >> $log_file;
            else
                echo "[MX5OPT] Error: remount failed!" >> $log_file;
                
                exit_flag=1;
            fi;
        else
            echo "[MX5OPT]  partition is read-write" >> $log_file;
        fi;
    else
        echo "[MX5OPT] Error: cannot get" >> $log_file;
        echo "[MX5OPT] \t\tstate of $partition!" >> $log_file;
        
        exit_flag=1;
    fi;
else
    echo "[MX5OPT] Error: $partition not allowed!" >> $log_file;
    echo "[MX5OPT] \tpartition has to be:" >> $log_file;
    echo "[MX5OPT] \t/cache or /data or /system" >> $log_file;

    exit_flag=1;
fi;
if [ $exit_flag -eq 0 ] ;
then
    echo "[MX5OPT]  change access rights of $partition" >> $log_file;
    chmod 775 $partition;
    echo "[MX5OPT]  create directory for swap file" >> $log_file;
    mkdir -p $partition/$sub_dir;
    chmod 775 $partition/$sub_dir;
    echo "[MX5OPT] >other parameters:" >> $log_file;
    echo "[MX5OPT]  sub directory:\t"$sub_dir >> $log_file;
    swap_file=$partition/$sub_dir/$swap_file_name >> $log_file;
    echo "[MX5OPT]  swap file:\t"$swap_file >> $log_file;
    echo "[MX5OPT]  log file:\t"$log_file >> $log_file;
    echo "[MX5OPT]  swap size:\t"$swap_file_size_mb" MB" >> $log_file;
    echo "[MX5OPT]  min. free:\t"$min_free_space_mb" MB" >> $log_file;
    echo "[MX5OPT]  min. swap:\t"$min_swap_size_mb" MB" >> $log_file;
    echo "[MX5OPT]  swappiness:\t"$swappiness >> $log_file;
fi;

delete_flag=0;
if [ -e $swap_file -a $exit_flag -eq 0 ] ;
then
    current_size_mb=$(((`stat -t $swap_file | awk '{ print $2 }'`)/1024/1024));
    echo "[MX5OPT]  current swap:\t"$current_size_mb" MB" >> $log_file;
    echo "[MX5OPT] ---------swapfile exists-------------" >> $log_file;
    echo "[MX5OPT] >check free memory limit" >> $log_file;
    if [ $min_free_space_mb -gt $available_size_mb ] ;
    then
        echo "[MX5OPT]  min. free memory too low" >> $log_file;
        delete_flag=1;
    else
        echo "[MX5OPT]  min. free memory ok" >> $log_file;
        if [ $current_size_mb -gt $swap_file_size_mb ];
        then
            echo "[MX5OPT]  swap file requested smaller" >> $log_file;
            delete_flag=1
        fi;
        if [ $current_size_mb -lt $swap_file_size_mb ];
        then
            echo "[MX5OPT]  swap file requested larger";
            if [ $min_free_space_mb -lt $available_size_mb ]  >> $log_file;
            then
                echo "[MX5OPT]  min. free space not reached" >> $log_file;
                echo "[MX5OPT]  delete and resize swap";
                delete_flag=1;
            else
                echo "[MX5OPT]  min. free space reached" >> $log_file;
            fi;
        fi;
    fi;
fi;

if [ $delete_flag -eq 1 -a $exit_flag -eq 0 ] ;
then
    echo "[MX5OPT] >delete current swap file" >> $log_file;
    rm $swap_file;
    if [ ! -e $swap_file ] ; then current_size_mb=0; fi;
    echo "[MX5OPT]  reinitialize free space:" >> $log_file;
    available_blocks=`stat -t -f $partition | awk '{ print $7 }'`;
    block_size=`stat -t -f $partition | awk '{ print $5 }'`;
    available_size_mb=$((($available_blocks*($block_size/1024))/1024));
    echo "[MX5OPT]  free blocks:\t"$available_blocks" blocks" >> $log_file;
    echo "[MX5OPT]  block size:\t"$block_size" Byte" >> $log_file;
    echo "[MX5OPT]  free space:\t"$available_size_mb" MB" >> $log_file;
    echo "[MX5OPT]  current swap:\t"$current_size_mb" MB" >> $log_file;
fi;
if [ ! -e $swap_file -a $exit_flag -eq 0 ] ;
then
    echo "[MX5OPT] -------swapfile does not exist-------" >> $log_file;
    echo "[MX5OPT] >check requested size of swapfile" >> $log_file;
    if [ $swap_file_size_mb -le $(($available_size_mb-$min_free_space_mb)) ] ;
    then
        echo "[MX5OPT]  requested size OK" >> $log_file;
    else
        echo "[MX5OPT]  requested size too large" >> $log_file;
        echo "[MX5OPT]  autocorrect size";
        swap_file_size_mb=$(($available_size_mb-$min_free_space_mb));
        echo "[MX5OPT]  corrected size:\t"$swap_file_size_mb" MB" >> $log_file;
    fi;
    if [ $swap_file_size_mb -ge $min_swap_size_mb ] ;
    then
        echo "[MX5OPT]  create swapfile" >> $log_file;
        dd if=/dev/zero of=$swap_file bs=1048576 count=$swap_file_size_mb;
    else
        echo "[MX5OPT]  swapfile lower than min." >> $log_file;
    fi;
else
    echo "[MX5OPT]  actual swapfile matches" >> $log_file;
fi;
if [ -e $swap_file -a $exit_flag -eq 0 ] ;
then
    echo "[MX5OPT] >initialize swapfile" >> $log_file;
    echo "[MX5OPT]  create swapfile structure in file" >> $log_file;
    # uid 0=root / gid 1000=system
    chown 0.1000 $swap_file;
    chmod 666 $swap_file;
    mkswap $swap_file;

    echo "[MX5OPT]  activate swapfile" >> $log_file;
    swapon $swap_file;

    echo "[MX5OPT]  set swappiness=($swappiness)" >> $log_file;
#   chmod 666 /proc/sys/vm/swappiness;
    echo $swappiness > /proc/sys/vm/swappiness;
else
    echo "[MX5OPT] ERROR: creation of swapfile failed! -" >> $log_file;
    exit_flag=1;
fi;

# cache pressure
echo "[MX5OPT] Setting cache pressure to 300" >> $log_file;
chmod 644 /proc/sys/vm/*
sysctl -e -w vm.vfs_cache_pressure=364

# set CPU and kernel settings
echo "[MX5OPT] Configuring CPU settings" >> $log_file;
echo "500" > /proc/sys/vm/dirty_writeback_centisecs
echo "200" > /proc/sys/vm/dirty_expire_centisecs
echo "10" > /proc/sys/vm/dirty_background_ratio
echo "30" > /proc/sys/vm/dirty_ratio

echo "[MX5OPT] Configuring kernel parameters" >> $log_file;
if [ -e /proc/sys/kernel/softlockup_panic ]; then 
	echo "0" > /proc/sys/kernel/softlockup_panic
fi
if [ -e /proc/sys/kernel/panic_on_oops ]; then 
	echo "0" > /proc/sys/kernel/panic_on_oops
fi
if [ -e /proc/sys/kernel/panic ]; then 
	echo "0" > /proc/sys/kernel/panic
fi
if [ -e /proc/sys/kernel/hung_task_timeout_secs ]; then 
   echo "0" > /proc/sys/kernel/hung_task_timeout_secs
fi

# RAM optimization
echo "[MX5OPT] Configuring RAM optimization settings" >> $log_file;
STL=`ls -d /sys/block/stl*` 2> /dev/null
BML=`ls -d /sys/block/bml*` 2> /dev/null
MMC=`ls -d /sys/block/mmc*` 2> /dev/null
ZRM=`ls -d /sys/block/zram*` 2> /dev/null
MTD=`ls -d /sys/block/mtd*` 2> /dev/null
RAM=`ls -d /sys/block/ram*` 2> /dev/null
LP=`ls -d /sys/block/loop*` 2> /dev/null

for S in $STL $BML $MMC $ZRM $MTD $RAM; do
	if [ -e $S/queue/rq_affinity ]; then
		echo "2" > $S/queue/rq_affinity
	fi
done

echo "[MX5OPT] Configuring OOM optimization settings" >> $log_file;
sysctl -e -w vm.oom_dump_tasks=1
sysctl -e -w vm.oom_kill_allocating_task=0

echo "85" > /proc/sys/vm/swappiness;

echo "[MX5OPT] Configuring VM minfree values" >> $log_file;
chmod 644 /sys/module/lowmemorykiller/parameters/minfree
echo "1128,2152,2668,8192,12288,16384"> /sys/module/lowmemorykiller/parameters/minfree

echo "[MX5OPT] Killing unnecessary processes" >> $log_file;
killall -9 com.google.android.gms
killall -9 com.google.android.gms.persistent
killall -9 com.google.process.gapps
killall -9 com.google.android.gsf
killall -9 com.google.android.gsf.persistent
killall -9 audit
killall -9 com.samsung.android.sm.ui.battery.BatteryOptimizeActivity
killall -9 com.samsung.android.sm.ui.notification.BatteryHeadUpNotificationService
killall -9 com.samsung.android.sm.ui.notification.BatteryUsageAlertsActivity
pm disable com.samsung.android.sm/com.samsung.android.sm.ui.battery.BatteryOptimizeActivity
pm disable com.samsung.android.sm/com.samsung.android.sm.ui.notification.BatteryHeadUpNotificationService
pm disable com.samsung.android.sm/com.samsung.android.sm.ui.notification.BatteryUsageAlertsActivity

if [ "`pgrep media`" ] && [ "`pgrep mediaserver`" ]; then
$busybox killall -9 android.process.media;
$busybox killall -9 mediaserver;
fi

echo "[MX5OPT] Configuring application priority settings" >> $log_file;
renice -15 `pidof android.process.acore`
renice -18 `pidof com.android.phone`
renice -16 `pidof com.android.mms`
renice -15 `pidof com.sec.android.inputmethod.latin`
renice -20 `pidof com.android.systemui`
renice -10 `pidof com.android.settings`
renice -9 `pidof com.android.vending`
renice -9 `pidof com.sec.android.app.launcher`
renice -12 `pidof com.sec.android.app.music`
renice -11 `pidof com.sec.android.gallery3d`
renice -12 `pidof com.sec.android.app.camera`

# Kill Google services
mount -o remount,rw /
mount -o remount,rw rootfs
mount -o remount,rw /system

echo "[MX5OPT] Configuring Google Services for battery optimization" >> $log_file;
pm disable com.google.android.gms/.ads.settings.AdsSettingsActivity
pm disable com.google.android.gms/com.google.android.location.places.ui.aliaseditor.AliasEditorActivity
pm disable com.google.android.gms/com.google.android.location.places.ui.aliaseditor.AliasEditorMapActivity
pm disable com.google.android.gms/com.google.android.location.settings.ActivityRecognitionPermissionActivity
pm disable com.google.android.gms/com.google.android.location.settings.GoogleLocationSettingsActivity
pm disable com.google.android.gms/com.google.android.location.settings.LocationHistorySettingsActivity
pm disable com.google.android.gms/com.google.android.location.settings.LocationSettingsCheckerActivity
pm disable com.google.android.gms/.usagereporting.settings.UsageReportingActivity
pm disable com.google.android.gms/.ads.adinfo.AdvertisingInfoContentProvider
pm disable com.google.android.gms/com.google.android.location.reporting.service.ReportingContentProvider
pm disable com.google.android.gms/com.google.android.location.internal.LocationContentProvider
pm enable com.google.android.gms/.common.stats.net.contentprovider.NetworkUsageContentProvider
pm disable com.google.android.gms/com.google.android.gms.ads.config.GServicesChangedReceiver
pm disable com.google.android.gms/com.google.android.contextmanager.systemstate.SystemStateReceiver
pm disable com.google.android.gms/.ads.jams.SystemEventReceiver
pm disable com.google.android.gms/.ads.config.FlagsReceiver
pm disable com.google.android.gms/.ads.social.DoritosReceiver
pm disable com.google.android.gms/.analytics.AnalyticsReceiver
pm disable com.google.android.gms/.analytics.internal.GServicesChangedReceiver
pm disable com.google.android.gms/.common.analytics.CoreAnalyticsReceiver
pm enable com.google.android.gms/.common.stats.GmsCoreStatsServiceLauncher
pm disable com.google.android.gms/com.google.android.location.internal.AnalyticsSamplerReceiver
pm enable com.google.android.gms/.checkin.CheckinService$ActiveReceiver
pm enable com.google.android.gms/.checkin.CheckinService$ClockworkFallbackReceiver
pm enable com.google.android.gms/.checkin.CheckinService$ImposeReceiver
pm enable com.google.android.gms/.checkin.CheckinService$SecretCodeReceiver
pm enable com.google.android.gms/.checkin.CheckinService$TriggerReceiver
pm enable com.google.android.gms/.checkin.EventLogService$Receiver
pm disable com.google.android.gms/com.google.android.location.reporting.service.ExternalChangeReceiver
pm enable com.google.android.gms/com.google.android.location.reporting.service.GcmRegistrationReceiver
pm enable com.google.android.gms/com.google.android.location.copresence.GcmRegistrationReceiver
pm disable com.google.android.gms/com.google.android.location.copresence.GservicesBroadcastReceiver
pm disable com.google.android.gms/com.google.android.location.internal.LocationProviderEnabler
pm disable com.google.android.gms/com.google.android.location.internal.NlpNetworkProviderSettingsUpdateReceiver
pm disable com.google.android.gms/com.google.android.location.network.ConfirmAlertActivity$LocationModeChangingReceiver
pm disable com.google.android.gms/com.google.android.location.places.ImplicitSignalsReceiver
pm disable com.google.android.gms/com.google.android.libraries.social.mediamonitor.MediaMonitor
pm enable com.google.android.gms/.location.copresence.GcmBroadcastReceiver
pm enable com.google.android.gms/.location.reporting.service.GcmBroadcastReceiver
pm enable com.google.android.gms/.social.location.GservicesBroadcastReceiver
pm disable com.google.android.gms/.update.SystemUpdateService$Receiver
pm disable com.google.android.gms/.update.SystemUpdateService$OtaPolicyReceiver
pm disable com.google.android.gms/.update.SystemUpdateService$SecretCodeReceiver
pm disable com.google.android.gms/.update.SystemUpdateService$ActiveReceiver
pm disable com.google.android.gms/com.google.android.contextmanager.service.ContextManagerService
pm enable com.google.android.gms/.ads.AdRequestBrokerService
pm disable com.google.android.gms/.ads.GservicesValueBrokerService
pm disable com.google.android.gms/.ads.identifier.service.AdvertisingIdNotificationService
pm enable com.google.android.gms/.ads.identifier.service.AdvertisingIdService
pm disable com.google.android.gms/.ads.jams.NegotiationService
pm disable com.google.android.gms/.ads.pan.PanService
pm enable com.google.android.gms/.ads.social.GcmSchedulerWakeupService
pm disable com.google.android.gms/.analytics.AnalyticsService
pm disable com.google.android.gms/.analytics.internal.PlayLogReportingService
pm disable com.google.android.gms/.analytics.service.AnalyticsService
pm disable com.google.android.gms/.analytics.service.PlayLogMonitorIntervalService
pm disable com.google.android.gms/.analytics.service.RefreshEnabledStateService
pm disable com.google.android.gms/.auth.be.proximity.authorization.userpresence.UserPresenceService
pm disable com.google.android.gms/.common.analytics.CoreAnalyticsIntentService
pm enable com.google.android.gms/.common.stats.GmsCoreStatsService
pm enable com.google.android.gms/.backup.BackupStatsService
pm disable com.google.android.gms/.deviceconnection.service.DeviceConnectionAsyncService
pm disable com.google.android.gms/.deviceconnection.service.DeviceConnectionServiceBroker
pm disable com.google.android.gms/.wallet.service.analytics.AnalyticsIntentService
pm enable com.google.android.gms/.checkin.CheckinService
pm enable com.google.android.gms/.checkin.EventLogService
pm disable com.google.android.gms/com.google.android.location.internal.AnalyticsUploadIntentService
pm disable com.google.android.gms/com.google.android.location.reporting.service.DeleteHistoryService
pm disable com.google.android.gms/com.google.android.location.reporting.service.DispatchingService
pm disable com.google.android.gms/com.google.android.location.reporting.service.InternalPreferenceServiceDoNotUse
pm disable com.google.android.gms/com.google.android.location.reporting.service.LocationHistoryInjectorService
pm disable com.google.android.gms/com.google.android.location.reporting.service.ReportingAndroidService
pm disable com.google.android.gms/com.google.android.location.reporting.service.ReportingSyncService
pm disable com.google.android.gms/com.google.android.location.activity.HardwareArProviderService
pm enable com.google.android.gms/com.google.android.location.fused.FusedLocationService
pm enable com.google.android.gms/com.google.android.location.fused.service.FusedProviderService
pm enable com.google.android.gms/com.google.android.location.geocode.GeocodeService
pm enable com.google.android.gms/com.google.android.location.geofencer.service.GeofenceProviderService
pm enable com.google.android.gms/com.google.android.location.internal.GoogleLocationManagerService
pm disable com.google.android.gms/com.google.android.location.places.PlaylogService
pm enable com.google.android.gms/com.google.android.location.places.service.GeoDataService
pm enable com.google.android.gms/com.google.android.location.places.service.PlaceDetectionService
pm disable com.google.android.gms/com.google.android.libraries.social.mediamonitor.MediaMonitorIntentService
pm disable com.google.android.gms/.config.ConfigService
pm enable com.google.android.gms/.stats.PlatformStatsCollectorService
pm enable com.google.android.gms/.usagereporting.service.UsageReportingService
pm enable com.google.android.gms/.update.SystemUpdateService
pm enable com.google.android.gms/com.google.android.location.network.ConfirmAlertActivity
pm enable com.google.android.gms/com.google.android.location.network.LocationProviderChangeReceiver
pm enable com.google.android.gms/com.google.android.location.internal.server.GoogleLocationService
pm enable com.google.android.gms/com.google.android.location.internal.PendingIntentCallbackService
pm enable com.google.android.gms/com.google.android.location.network.NetworkLocationService
pm enable com.google.android.gms/com.google.android.location.util.PreferenceService
pm disable com.google.android.gsf/.update.SystemUpdateActivity
pm disable com.google.android.gsf/.update.SystemUpdatePanoActivity
pm enable com.google.android.gsf/com.google.android.gsf.checkin.CheckinService\$Receiver
pm enable com.google.android.gsf/com.google.android.gsf.checkin.CheckinService\$SecretCodeReceiver
pm enable com.google.android.gsf/com.google.android.gsf.checkin.CheckinService\$TriggerReceiver
pm enable com.google.android.gsf/.checkin.EventLogService$Receiver
pm disable com.google.android.gsf/.update.SystemUpdateService$Receiver
pm disable com.google.android.gsf/.update.SystemUpdateService$SecretCodeReceiver
pm enable com.google.android.gsf/.checkin.CheckinService
pm enable com.google.android.gsf/.checkin.EventLogService
pm enable com.google.android.gms/.update.SystemUpdateActivity
pm enable com.google.android.gms/.update.SystemUpdateService
pm enable com.google.android.gms/.update.SystemUpdateService$ActiveReceiver
pm enable com.google.android.gms/.update.SystemUpdateService$Receiver
pm enable com.google.android.gms/.update.SystemUpdateService$SecretCodeReceiver
pm enable com.google.android.gsf/.update.SystemUpdateActivity
pm enable com.google.android.gsf/.update.SystemUpdatePanoActivity
pm enable com.google.android.gsf/.update.SystemUpdateService
pm enable com.google.android.gsf/.update.SystemUpdateService$Receiver
pm enable com.google.android.gsf/.update.SystemUpdateService$SecretCodeReceiver

echo "[MX5OPT] Script finished executing!" >> $log_file;

#-------------------------------------------
#   EOF
#-------------------------------------------